package handler

import (
	"errors"
	"net/http"

	"github.com/zeromicro/go-zero/core/logx"
	"github.com/zeromicro/go-zero/rest/httpx"

	"fusenapi/utils/auth"
	"fusenapi/utils/basic"

	"fusenapi/server/home-user-auth/internal/logic"
	"fusenapi/server/home-user-auth/internal/svc"
	"fusenapi/server/home-user-auth/internal/types"
)

var wantJwt = true

func UserAddressListHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		var userinfo *auth.UserInfo
		var err error

		if wantJwt {
			userinfo, err = auth.ParseJwtToken(w, r, &svcCtx.Config.Auth.AccessSecret)
			if err != nil {
				httpx.OkJsonCtx(r.Context(), w, &basic.Response{
					Code:    401,
					Message: "unauthorized",
				})
				logx.Info("unauthorized:", err.Error())
				return
			}
		}

		var req types.Request
		// 如果端点有请求结构体，则使用httpx.Parse方法从HTTP请求体中解析请求数据
		if err := httpx.Parse(r, &req); err != nil {
			httpx.OkJsonCtx(r.Context(), w, &basic.Response{
				Code:    510,
				Message: "parameter error",
			})
			logx.Info(err)
			return
		}
		// 创建一个业务逻辑层实例
		l := logic.NewUserAddressListLogic(r.Context(), svcCtx)
		resp := l.UserAddressList(&req, userinfo)
		// 如果响应不为nil，则使用httpx.OkJsonCtx方法返回JSON响应;
		// 否则，发送500内部服务器错误的JSON响应并记录错误消息logx.Error。
		if resp != nil {
			httpx.OkJsonCtx(r.Context(), w, resp)
		} else {
			err := errors.New("server logic is error, resp must not be nil")
			httpx.ErrorCtx(r.Context(), w, err)
			logx.Error(err)
		}
	}
}
